class String
  # Converts a timestring to seconds with milliseconds part support
  def as_seconds
    # Check if input string has a valid format
    raise "Invalid timestring format: #{self}" if not self.match(/^\d{1,}:[0-5]?[0-9](:[0-5]?[0-9](\.\d+)?)?$/)

    # Split input string by ":" char and convert each part to float
    hours, minutes, seconds = self.split(":").map(&:to_f)

    # Seconds part could be missing, so set it to 0 by default
    seconds ||= 0

    return hours * 3600 + minutes * 60 + seconds
  end

  # Converts a timestring to hours
  def as_hours
    return self.as_seconds.to_f / 3600
  end

  def blank?
    return self.strip == ""
  end

  def present?
    return (not self.blank?)
  end

  def is_true?
    return ["y", "yes", "t", "true"].include?(self.strip.downcase)
  end

  def is_false?
    return ["n", "no", "f", "false"].include?(self.strip.downcase)
  end
end